""" This is the entrypoint for ingestion launching """

import logging
import sys
from pathlib import Path

# pylint: disable=R0903

from ingest_envoy.ingestion_manifest_writer import EvlaCalIngestionManifestWriter
from ingest_envoy.utilities import ScienceProductType

logger = logging.getLogger(__name__)
logger.setLevel(logging.INFO)
logger.addHandler(logging.StreamHandler(sys.stdout))


class IngestionManifest:
    """needed for ingestion-launching interface"""

    def __init__(self, staging_source_dir: str, ingestion_type: str, locator: str):
        self.ingest_path = Path(staging_source_dir)
        self.sp_type = ScienceProductType.from_str(ingestion_type)
        self.locator = locator

    def create(self):
        """
        Create the ingestion manifest in this directory for a product of this type,
        identified by this locator.

        :return:
        """

        if self.sp_type != ScienceProductType.EVLA_CAL:
            return NotImplementedError(
                f"Don't yet know how to handle {self.sp_type.value} science product"
            )

        writer = EvlaCalIngestionManifestWriter(self.ingest_path)
        writer.write_evla_cal_manifest(self.locator)
